SystemdFdName

Struct SystemdFdName 

pub struct SystemdFdName<'a>(/* private fields */);
A validated name for a systemd socket-activation file descriptor.

Names appear in the LISTEN_FDNAMES environment variable as colon-separated values. The constructor validates that the name conforms to systemd’s fdname_is_valid() rules: at most 255 printable ASCII characters, excluding :.

use cap_std_ext::cmdext::SystemdFdName;
let name = SystemdFdName::new("varlink");

Implementations

Source

impl<'a> SystemdFdName<'a>

pub const fn new(name: &'a str) -> Self

Create a new SystemdFdName, panicking if name is invalid.

Panics

Panics if name is longer than 255 bytes or contains any character that is not printable ASCII (i.e. control characters, DEL, non-ASCII bytes, or :).

pub fn as_str(&self) -> &'a str

Return the name as a string slice.