Module cap_std_ext::dirext

source ·
Extensions for cap_std::fs::Dir. Key features here include:

  • “optional” variants that return Result<Option<T>> for nonexistent paths, when it is a normal case that paths may not exist.
  • A helper to update timestamps
  • “atomic write” APIs that create a new file, then rename over the existing one to avoid half-written updates to files.

Traits